summaryrefslogtreecommitdiffstats
path: root/amarok/src/scriptmanager.cpp
diff options
context:
space:
mode:
authorSlávek Banko <slavek.banko@axis.cz>2014-09-26 17:01:09 +0200
committerSlávek Banko <slavek.banko@axis.cz>2014-09-26 17:01:09 +0200
commit4efcfec98c8b702b2dfea3b0f5d824e463e6ef3e (patch)
tree3c7c8f666d1715bd4329b4641b68b012ac4e818b /amarok/src/scriptmanager.cpp
parentb78d37d1dd85ac555b522e6aa18f893f2eca03ad (diff)
downloadamarok-4efcfec98c8b702b2dfea3b0f5d824e463e6ef3e.tar.gz
amarok-4efcfec98c8b702b2dfea3b0f5d824e463e6ef3e.zip
Use TDE data source for new stuff
Diffstat (limited to 'amarok/src/scriptmanager.cpp')
-rw-r--r--amarok/src/scriptmanager.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/amarok/src/scriptmanager.cpp b/amarok/src/scriptmanager.cpp
index c9abc2fd..dbdfdc32 100644
--- a/amarok/src/scriptmanager.cpp
+++ b/amarok/src/scriptmanager.cpp
@@ -61,10 +61,10 @@
#include <ktextedit.h>
#include <twin.h>
-#include <knewstuff/downloaddialog.h> // knewstuff script fetching
-#include <knewstuff/engine.h> // "
-#include <knewstuff/knewstuff.h> // "
-#include <knewstuff/provider.h> // "
+#include <tdenewstuff/downloaddialog.h> // tdenewstuff script fetching
+#include <tdenewstuff/engine.h> // "
+#include <tdenewstuff/knewstuff.h> // "
+#include <tdenewstuff/provider.h> // "
namespace Amarok {
@@ -111,11 +111,11 @@ namespace Amarok {
/**
* GHNS Customised Download implementation.
*/
-class AmarokScriptNewStuff : public KNewStuff
+class AmarokScriptNewStuff : public TDENewStuff
{
public:
AmarokScriptNewStuff(const TQString &type, TQWidget *parentWidget=0)
- : KNewStuff( type, parentWidget )
+ : TDENewStuff( type, parentWidget )
{}
bool install( const TQString& fileName )
@@ -488,12 +488,12 @@ ScriptManager::recurseInstall( const KArchiveDirectory* archiveDir, const TQStri
void
ScriptManager::slotRetrieveScript()
{
// Delete KNewStuff's configuration entries. These entries reflect which scripts
// are already installed. As we cannot yet keep them in sync after uninstalling
// scripts, we deactivate the check marks entirely.
- Amarok::config()->deleteGroup( "KNewStuffStatus" );
+ Amarok::config()->deleteGroup( "TDENewStuffStatus" );
- // we need this because KNewStuffGeneric's install function isn't clever enough
+ // we need this because TDENewStuffGeneric's install function isn't clever enough
AmarokScriptNewStuff *kns = new AmarokScriptNewStuff( "amarok/script", this );
KNS::Engine *engine = new KNS::Engine( kns, "amarok/script", this );
KNS::DownloadDialog *d = new KNS::DownloadDialog( engine, this );
@@ -501,7 +501,7 @@ ScriptManager::slotRetrieveScript()
// you have to do this by hand when providing your own Engine
KNS::ProviderLoader *p = new KNS::ProviderLoader( this );
TQObject::connect( p, TQT_SIGNAL( providersLoaded(Provider::List*) ), d, TQT_SLOT( slotProviders (Provider::List *) ) );
- p->load( "amarok/script", "http://amarok.kde.org/knewstuff/amarokscripts-providers.xml" );
+ p->load( "amarok script", "https://www.trinitydesktop.org/ocs/providers.xml" );
d->exec();
}
@@ -488,12 +488,12 @@ ScriptManager::recurseInstall( const KArchiveDirectory* archiveDir, const TQStri
ScriptManager::slotRetrieveScript()
{
- // Delete KNewStuff's configuration entries. These entries reflect which scripts
+ // Delete TDENewStuff's configuration entries. These entries reflect which scripts
// are already installed. As we cannot yet keep them in sync after uninstalling
// scripts, we deactivate the check marks entirely.